import { AuthApi } from '@/apis/auth';
import loginBg from '@/assets/images/login-bg.png';
import { useAuth } from '@/hooks/useAuth';
import { useUserStore } from '@/store/user';
import { Check } from '@nutui/icons-react';
import { Button, Input, Toast } from '@nutui/nutui-react';
import { useRequest, useToggle } from 'ahooks';
import clsx from 'clsx';
import { CSSProperties, useState } from 'react';
import { useNavigate } from 'react-router-dom';
import { Md5 } from 'ts-md5';
import styles from './login.module.scss';

const inputStyle = {
  background: 'transparent',
  lineHeight: '50px',
  padding: '0 24px',
  color: '#262628',
} as CSSProperties;

function LoginPage() {
  const navigate = useNavigate();
  const { login: loginAuth } = useAuth();
  const { setToken, setStringProperty, username, password, updateUserInfo } = useUserStore();
  const [isRemember, { toggle: toggleRemember }] = useToggle(!!password);
  const [state, setState] = useState({
    username: username || '',
    password: password || '',
  });

  const { loading, runAsync } = useRequest(AuthApi.login, {
    manual: true,
    onSuccess: data => {
      setToken(data.token);
      loginAuth();
      if (isRemember) {
        setStringProperty('username', state.username);
        setStringProperty('password', state.password);
      } else {
        setStringProperty('username', '');
        setStringProperty('password', '');
      }
      updateUserInfo();
      navigate('/portal');
    },
    onError: error => {
      Toast.show({
        icon: 'fail',
        content: error.message,
      });
    },
  });

  const handleLogin = async () => {
    if (!state.username || !state.password) {
      Toast.show('请输入账号和密码');
      return;
    }
    await runAsync({
      username: state.username,
      password: Md5.hashStr(state.password),
    });
  };

  return (
    <div>
      <div className={styles.loginHeader} style={{ backgroundImage: `url(${loginBg})` }}>
        <div className={styles.loginHeaderContent}>
          <div className={styles.hello}>
            <div>Hello～</div>
            <div>欢迎登录，</div>
          </div>
          <div className={styles.system}>
            <div>双重预防</div>
            <div>信息管理系统！</div>
          </div>
        </div>
      </div>
      <div>
        <div className={styles.formPanel}>
          <div className={clsx(styles.field, 'pt-4')}>
            <div className={styles.label}>账号</div>
            <div className={styles.input}>
              <Input
                style={inputStyle}
                placeholder="请输入账号"
                value={state.username}
                onChange={value => setState({ ...state, username: value })}
              />
            </div>
          </div>
          <div className={styles.field}>
            <div className={styles.label}>密码</div>
            <div className={styles.input}>
              <Input
                style={inputStyle}
                type="password"
                placeholder="请输入密码"
                value={state.password}
                onChange={value => setState({ ...state, password: value })}
              />
            </div>
          </div>
          <div className="py-4 px-2">
            <div className="flex items-center">
              <label className={styles.checkbox}>{isRemember && <Check color="#4CD964" />}</label>
              <span className={styles.checkboxLabel} onClick={toggleRemember}>
                记住密码
              </span>
            </div>
          </div>
          <div className="pt-8">
            <Button
              type="primary"
              size="large"
              style={{ height: '44px' }}
              color="linear-gradient(to right, #3987F3, #1D47CB)"
              block
              onClick={handleLogin}
              loading={loading}
            >
              登录
            </Button>
          </div>
        </div>
      </div>
    </div>
  );
}

export default LoginPage;
