import { AuthApi } from '@/apis/auth';
import { aesDecrypt, aesEncrypt, ENCRYPT_SECRET } from '@/utils/encrypt';
import { create } from 'zustand';
import { createJSONStorage, persist, StateStorage } from 'zustand/middleware';

interface UserState {
  userInfo?: Auth.User;
  token?: string;
  username?: string;
  password?: string;

  setToken: (token: string) => void;
  getToken: () => string;
  setUserInfo: (userInfo: UserState['userInfo']) => void;
  updateUserInfo: () => Promise<void>;
  setStringProperty: <T extends keyof UserState>(key: T, value: UserState[T]) => void;
}
const initData: Partial<UserState> = {
  token: '',
  username: '',
  password: '',
};

const SecureStorage: StateStorage = {
  getItem: async (name: string): Promise<string | null> => {
    const value = localStorage.getItem(name) || '';
    return aesDecrypt(value, ENCRYPT_SECRET);
  },
  setItem: async (name: string, value: string): Promise<void> => {
    localStorage.setItem(name, aesEncrypt(value as string, ENCRYPT_SECRET));
  },
  removeItem: async (name: string): Promise<void> => {
    localStorage.removeItem(name);
  },
};

export const useUserStore = create<UserState>()(
  persist(
    (set, get) => ({
      ...initData,
      setUserInfo: (userInfo: UserState['userInfo']) => set({ userInfo }),
      updateUserInfo: async () => {
        const user = await AuthApi.getCurrentUser();
        return set({ userInfo: { ...user } });
      },

      setToken: (token: string) => set({ token }),
      getToken: () => {
        return get().token || '';
      },
      setStringProperty: (key, value) => set({ [key]: value }),
    }),
    {
      name: 'user-storage',
      storage: createJSONStorage(() => SecureStorage),
    }
  )
);
